@@ -24,6 +24,22 @@ def isFileInRepo(repo, path_to_file):
             return True
     return False
 
+def get_changed_files_in_commit(repo, commit):
+    base_commit = repo.commit(commit)
+    parent_commit = repo.commit(f"{commit}^")
+    changed_files = []
+    for diff in base_commit.diff(parent_commit):
+        if diff.a_blob:
+            changed_files.append(diff.a_blob.path)
+        if diff.b_blob:
+            changed_files.append(diff.b_blob.path)
+    return list(set(changed_files))
+
+def is_part_of_patch(repo, commit, filename):
+    files = get_changed_files_in_commit(repo, commit)
+    LOGGER.debug(f"Commit {commit} as following changed files: {files}")
+    return filename in files
+
 
 @log_decorator
 def prepare(rest, git_repo, args, gerrit_config):
@@ -484,7 +500,7 @@ def get_changes_submitted_together(rest, changeid):
             raise RuntimeError(f"Provided change ({changeid}) cannot be found on remote gerrit server.")
 
 
-def _get_payload(git_repo, payload_json, path_prefixes, robot_id, robot_run_id):
+def _get_payload(git_repo, commit, payload_json, path_prefixes, robot_id, robot_run_id):
     def trim_prefixes(name, prefixes):
         for prefix in prefixes:
             name = name.lstrip(prefix)
@@ -507,12 +523,17 @@ def _get_payload(git_repo, payload_json, path_prefixes, robot_id, robot_run_id):
 
     comments = payload["comments"].copy()
     payload["robot_comments"] = {}
+    issues = 0
     for key in comments:
         new_key = trim_prefixes(key, prefixes)
         if not isFileInRepo(git_repo, new_key):
             LOGGER.debug(f"File {key} contains issues reported by static analysis but its not part of the git repository at {git_repo.working_dir} - Skipping!")
             continue
 
+        if not is_part_of_patch(git_repo, commit, new_key):
+            LOGGER.debug(f"File {new_key} contains issues reported by static analysis but its not part of the currently processed commit {commit} - Skipping!")
+            continue
+
         for item in comments[key]:
             item["robot_id"] = "clang-tidy"
             res = regex.match(item["message"])
@@ -520,11 +541,18 @@ def _get_payload(git_repo, payload_json, path_prefixes, robot_id, robot_run_id):
                 item["message"] = f"{res.group('prio')} {res.group('msg')}"
             item["robot_id"] = robot_id
             item["robot_run_id"] = robot_run_id
+            issues = issues + 1
 
         payload["robot_comments"][new_key] = comments[key].copy()
 
     del payload["comments"]
 
+    extra = ""
+    report_url = os.environ.get("CC_REPORT_URL", None)
+    if report_url:
+        extra = f"See {report_url} for more details"
+
+    payload["message"] = f"Jenkins found {issues} issue(s) within this pull request. Some issues might have been filtered. {extra}"
     LOGGER.debug(json.dumps(payload, indent=4))
     return payload
 
@@ -548,7 +576,7 @@ def review(rest, git_repo, args, gerrit_config):
 
     change_details = get_change_detail(rest, args.changeid)
     rev = get_rev(change_details)
-    payload = _get_payload(git_repo, args.payload, args.path_prefixes, args.robot_id, args.robot_run_id)
+    payload = _get_payload(git_repo, args.commit, args.payload, args.path_prefixes, args.robot_id, args.robot_run_id)
     payload["omit_duplicate_comments"] = True
     payload["notify"] = "NONE"
 
